# osm4gpd: OpenStreetMap to GeoPandas Parser

![Test](https://github.com/knthls/osm4gpd/actions/workflows/test.yml/badge.svg)
![Release](https://img.shields.io/github/v/release/knthls/osm4gpd)
[![codecov](https://codecov.io/gh/knthls/osm4gpd/branch/main/graph/badge.svg?token=OSNRL1NSNH)](https://codecov.io/gh/knthls/osm4gpd)

## Introduction

Osm4gpd is a Python package that provides a fairly memory-efficient parser to load OpenStreetMap data in its native protobuf format into a sparse GeoPandas DataFrame. This package aims to help users work with large OSM datasets while minimizing memory usage and providing a convenient interface for data manipulation.
